==> ver.B.b16.14.tar.gz: ver.B.b16.14/env/src/arch/win/std/utils/u_file.c <==
/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/

#define U_FILE_LIB

#include <stdio.h>
#include <errno.h>
#include <io.h>
#include <fcntl.h>
#include	"machine/include.h"
#include	"u_file.h"

/* for gbs/lib/pmd/database.c:line266 log_printf */
int open_err_sub_code;
int open_err_main_code;
int open_filespace_point;
int open_pdb_point;
int u_open_point;
int ufr_point;

int
u_open(char * filename,int flags,int mode)
{
	// add O_BINARY by default
	return open(filename,flags|O_BINARY,mode);
}


int
u_close(int fd)
{
	return close(fd);
}

int
u_write(int fd,void * data,int len)
{
	return write(fd,data,len);
}

int
u_read(int fd,void * data,int len)
{
	return read(fd,data,len);
}

int
u_lseek(int fd,int ofs,int where)
{
	return lseek(fd,ofs,where);
}

int
u_open64(char * filename,int flags,int mode)
{
	return open64(filename,flags|O_BINARY,mode);
}

INTEGER64
u_lseek64(int fd,INTEGER64 ofs,int where)
{
	return lseek64(fd,ofs,where);
}

int
u_unlink(char * path)
{
	return unlink(path);
}

int
u_rmdir(char * path)
{
	return rmdir(path);
}


char *
u_getenv(char * name)
{
	return getenv(name);
}

==> ver.B.b17.12.tar.gz: ver.B.b17.12/env/src/arch/win/std/utils/u_file.c <==
/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/

#define U_FILE_LIB

#include <stdio.h>
#include <errno.h>
#include <io.h>
#include <fcntl.h>
#include	"machine/include.h"
#include	"u_file.h"

/* for gbs/lib/pmd/database.c:line266 log_printf */
int open_err_sub_code;
int open_err_main_code;
int open_filespace_point;
int open_pdb_point;
int u_open_point;
int ufr_point;

int
u_open(char * filename,int flags,int mode)
{
	// add O_BINARY by default
	return open(filename,flags|O_BINARY,mode);
}


int
u_close(int fd)
{
	return close(fd);
}

int
u_write(int fd,void * data,int len)
{
	return write(fd,data,len);
}

int
u_read(int fd,void * data,int len)
{
	return read(fd,data,len);
}

int
u_lseek(int fd,int ofs,int where)
{
	return lseek(fd,ofs,where);
}

int
u_open64(char * filename,int flags,int mode)
{
	return open64(filename,flags|O_BINARY,mode);
}

INTEGER64
u_lseek64(int fd,INTEGER64 ofs,int where)
{
	return lseek64(fd,ofs,where);
}

int
u_unlink(char * path)
{
	return unlink(path);
}

int
u_rmdir(char * path)
{
	return rmdir(path);
}


char *
u_getenv(char * name)
{
	return getenv(name);
}

int
secure_close(int fd)
{
	u_close(fd);
	return 0;
}


int
secure_fclose(FILE * fd)
{
	fclose(fd);
	return 0;
}

int
secure_closedir(DIR * d)
{
	closedir(d);
	return 0;
}
